import pandas as pd
import matplotlib.pyplot as plt
from db import Database
import utils

# create the database object
db = Database()
# connect to the database using default credentials
db.connect()

print("\n### running lab script")


def example1():
    '''function used to run an example query and show results'''
    # run query on the database server
    res = db.run_query("SELECT * FROM employee")
    show_results(res)


def example2(plot_mode):
    '''function used to run an example query, do some basic processing and show results'''
    # run query on the database server
    res = db.run_query("SELECT * FROM employee")
    # create a pandas dataframe and with the results from the database
    df = pd.DataFrame(res)
    print(df)

    # get a list of all salaries from the data
    salaries = list(df["salary"])
    # convert to float (real numbers)
    salaries = [float(sal) for sal in salaries]
    print(salaries)

    if plot_mode == 1:
        plt.stem(salaries)
        plt.title("salaries for each employee")
        plt.xlabel("employee")
        plt.ylabel("salary")
    elif plot_mode == 2:
        plt.hist(salaries)
        plt.title("number of employees having the same salary")
        plt.xlabel("salaries")
        plt.ylabel("number of employees")

    plt.show()


def show_results(res):
    '''function used to show results as dictionary, csv, and save to file'''
    print("\n\n## showing data as dictionary rows:\n")
    # display result as dictionary
    utils.print_dict(res)

    print("\n\n## showing data as csv rows:\n")
    # convert result to csv data
    res = utils.get_csv_data(res)
    # display csv data
    utils.print_csv_data(res)
    # write csv data to output file
    utils.write_csv_file(res)

# select the example
ex = 1


# the main switch (select between examples)
if ex == 1:
    example1()
elif ex == 2:
    example2(1)
elif ex == 3:
    example2(2)


## a more elegant switch if you want

# def example2_1():
#     return example2(1)
# def example2_2():
#     return example2(2)

# switcher = {
#     1: example1,
#     2: example2_1,
#     3: example2_2
# }

# func = switcher.get(ex, lambda: "Invalid example")
# func()


